@@ -91,10 +91,9 @@ class SSHRemote:
         return f"SSH: {self.host}:/{self.path}"
 
     def to_dvc_conf(self, key_store: Path):
-        d = {
-            "url": f"ssh://{self.host}{self.path}",
-            "user": self.user,
-        }
+        if self.host in _get_local_names():
+            return {"url": self.path}
+        d = {"url": f"ssh://{self.host}{self.path}", "user": self.user}
         if self.port:
             d["port"] = self.port
         if self.rsa_key:
@@ -133,8 +132,7 @@ class ZimmAuth:
 
         tmp_dir = TemporaryDirectory()
         ssh_rem = self._ssh_remotes[remote_name]
-        local_names = os.environ.get(LOCAL_HOST_NAMES_ENV_VAR, "").split(";")
-        if ssh_rem.host in local_names:
+        if ssh_rem.host in _get_local_names():
             ctx = LocalContext()
         else:
             key_path = Path(tmp_dir.name, "key")
@@ -158,7 +156,7 @@ class ZimmAuth:
     def dump_dvc(self, local=True, key_store=CONF_PATH):
         from dvc.config import Config
 
-        conf = Config()
+        conf = Config(Path(".dvc"))
         with conf.edit("local" if local else "global") as ced:
             ced["remote"] = {
                 k: v.to_dvc_conf(key_store) for k, v in self._remotes.items()
@@ -166,7 +164,6 @@ class ZimmAuth:
         self._dump_keys(key_store)
 
     def get_boto_bucket(self, remote_name):
-
         import boto3
 
         s3_rem = self._s3_remotes[remote_name]
@@ -206,3 +203,7 @@ class ZimmAuth:
     @property
     def _remotes(self) -> Dict[str, Union[S3Remote, SSHRemote]]:
         return {**self._s3_remotes, **self._ssh_remotes}
+
+
+def _get_local_names():
+    return os.environ.get(LOCAL_HOST_NAMES_ENV_VAR, "").split(";")
